;+
; NAME:
; 
;	ATANH
;	
; PURPOSE:
; 
;       Inverse of TANH
;
;       atanh z = 1/2 ln( (1+z)/(1-z) )
;	
; CALLING SEQUENCE:
; 
;       Result=ATANH(Input)
;
; MODIFICATION HISTORY:
;
;       David L. Windt, RXO, April 2013
;       davidwindt@gmail.com
;-
function atanh,z

;; if input is +1. or -1., don't return "Infinity", return machine
;; limit.
;;
;; if input is greater than 1 or less than -1, return NaN

case 1 of
    (z eq 1.) or (z eq -1.): result=(machar(/double)).xmax

    (z gt 1.) or (z lt -1.): result=!values.d_nan

    else: result=0.5d*alog((1.d +z) / (1.d -z))
endcase

return,result
end
