;+
; NAME:
; 
;	CIRCLE_FIT
;	
; PURPOSE:
; 
; 	Fit y=f(x) where:
; 	F(x) = yc+SQRT(r^2-(x-xc)^2)
;	(xc,yc)=circle center, r=circle radius
; 	
; CALLING SEQUENCE:
; 
;	YFIT = CIRCLE_FIT(X,Y,A)
;	
; INPUTS:
; 
;	X - independent variable, must be a vector.
;	
;       Y - dependent variable, must have the same number of points ;
;           as x.
;
;       A - initial guess at fit coefficienct [xc, yc, r]
;		
; OUTPUTS:
; 
;	YFIT - fitted function.
;	
; OPTIONAL OUTPUT PARAMETERS:
; 
;       A - Fit coefficients. a three element vector containing xc,
;           yc, and r.
;
; MODIFICATION HISTORY:
; 
;	Adapted from GAUSSFIT
;	
;	D. L. Windt, davidwindt@gmail.com
;	Aug 2010
;-
;

pro circle,x,a,f,pder
f=a[1]-SQRT(a[2]^2-(x-a[0])^2)
if n_params(0) le 3 then return ;need partial?
pder = fltarr(n_elements(x),3)  ;yes, make array.
pder(0,0) = -(x-a[0])/sqrt(a[2]^2-(x-a[0])^2)
pder(*,1) = 1.
pder(0,2) = -a[2]/sqrt(a[2]^2-(x-a[0])^2)
return
end

function circle_fit,x,y,a
on_error,2		
cm=check_math(0.,1.)		; Don't print math error messages.
n = n_elements(y)		;# of points.
return,curvefit(x,y,replicate(1.,n),a,sigmaa,funct='circle',itmax=1000) 
end
