;+
; NAME:
; 
;	DISPLAYED_TABLE_CELLS
;
; PURPOSE:
; 
;       This function returns a four-element vector
;
; CALLING SEQUENCE:
; 
;	Result = DISPLAYED_TABLE_CELLS(Table)
;
; INPUTS:
; 
;       Table - Widget id of the widget_table.
;
; OUTPUTS:
; 
;
; EXAMPLE:
;
;
; MODIFICATION HISTORY:
; 
; 	Daryl Atencio, Research Systems, Oct 2003
; 	
;                    
;-

function displayed_table_cells, table

; Get the index for the upper-left cell
  ul = widget_info(table, /table_view)
    
; Get the height for each row in an array
  rh = widget_info(table, /row_heights)
  
; Get the width for each column in an array
  cw = widget_info(table, /column_widths)
  
; Get the table widget's geometry
  g = widget_info(table, /geometry)  

; Padding for scroll bars.
  xc = 18
  yc = 18

; Find which cells beyond the upper-right cell are still visible
  wx = where(total(cw[ul[0]:*], /cumulative) gt (g.scr_xsize - xc), cntx)
  wy = where(total(rh[ul[1]:*], /cumulative) gt (g.scr_ysize - yc), cnty)

; Are all of the cells being displayed?
  mx = (cntx gt 0) ? min(wx)-1 : fix(g.xsize) - 1
  my = (cnty gt 0) ? min(wy)-1 : fix(g.ysize) - 1

; Return the displayed cells.
  return, [ul[0], ul[1], mx, my]
end
