;+
; NAME:
; 
;	ROT_MAT
;
; PURPOSE:
; 
;       Return a 2D rotation matrix.
;
; CALLING SEQUENCE:
; 
;	Result = ROT_MAT(Angle)
;
; INPUTS:
; 
;       Angle - Rotation angle in degrees.
;
; OUTPUTS:
; 
;       Result = [[cos(Angle*!dtor),-sin(Angle*!dtor)],
;                 [sin(Angle*!dtor), cos(Angle*!dtor)]
;
; EXAMPLE:
;
;	To rotate a vector X by an angle Theta:
;
;       X=[0.1,0.9]
;       X_=ROT_MAT(Theta)##X
;
; MODIFICATION HISTORY:
; 
; 	David L. Windt, December 2003
; 	
;       windt@astro.columbia.edu
;                    
;-
function rot_mat,angle

result=[[cos(angle*!dtor),-sin(angle*!dtor)], $
        [sin(angle*!dtor),cos(angle*!dtor)]]

return,result
end


