pro rxo_color, Start_index, Ncolors
;+
; NAME:
;	RXO_COLOR
;
; PURPOSE: Load a color table for the first 32 colors, exactly as the
;       TEK_COLOR procedure does. However this procedure uses
;       different colors for the top 16 color indices, presenting a
;       broader choice of colors for plotting.
;
; CATEGORY:
;	Graphics.
;
; CALLING SEQUENCE:
;	RXO_COLOR [[, Start_index] , Ncolors]
;
; INPUTS:
;	Start_index = optional starting index of palette.  If omitted,
;		use 0.
;	Ncolors = Number of colors to load.  32 is the max and the default.
; KEYWORD PARAMETERS:
;	None.
; OUTPUTS:
;	No explicit outputs.
; COMMON BLOCKS:
;	Colors.
; SIDE EFFECTS:
;	Ncolors color indices, starting at Start_index are loaded with
;	the Tektronix 4115 default color map.
; RESTRICTIONS:
;	None.
; PROCEDURE:
;	Just copy the colors.  This table is useful for the
;	display of graphics in that the colors are distinctive.
;
;	Basic colors are:  0 - black, 1 - white, 2 - red, 3 - green, 
;	4 - blue, 5 - cyan, 6 - magenta, 7 - yellow, 8 - orange, etc.
; MODIFICATION HISTORY:
;	DMS, Jan, 1989.
;	DMS, June, 1992.  Added colors common.
;	DMS, Apr, 1993, Added start_index and ncolors.
;
;       D.Windt, May 2013: same as TEK_COLOR, but top 16 colors are
;       different.
;       
;-
common colors, r_orig, g_orig, b_orig, r_curr, g_curr, b_curr

if n_elements(ncolors) le 0 then ncolors = 32
if n_elements(start_index) le 0 then start_index = 0

if n_elements(r_orig) lt (ncolors + start_index) then begin
    r_orig = bytscl(indgen(256), max=!d.table_size-1, min = 0)
    g_orig = r_orig
    b_orig = r_orig
endif

;; colors:
r=[000b,255,255,000,000,000,255,255,255,153,000,000,140,255,084,171, $
   215,128,064,102,153, 253,255,153,102,000,000,000,102,153,204,102]
g=[000b,255,000,255,000,255,000,255,127,212,255,127,000,000,084,171, $
   215,128,064,051,000, 051,255,255,153,102,000,051,153,102,153,051]
b=[000b,255,000,000,255,255,212,000,000,000,153,255,212,140,084,171, $
   215,128,064,000,000, 000,153,000,051,051,102,153,255,255,204,153]

;; trim?
if ncolors lt 32 then begin   
    r = r[0:ncolors-1]
    g = g[0:ncolors-1]
    b = b[0:ncolors-1]
endif
;; never over top:
s=start_index < (256 - ncolors)

r_orig[s] = r
g_orig[s] = g
b_orig[s] = b

tvlct, r_orig, g_orig, b_orig
r_curr = r_orig
g_curr = g_orig
b_curr = b_orig
end
