;+
; NAME:
; 
;	SECONDS2CLOCK
;
; PURPOSE:
; 
;       Convert a time value from seconds to a string of the form
;       "DAYS:HOURS:MINUTES:SECONDS.FRACTIONAL_SECONDS"
;
; CALLING SEQUENCE:
; 
;	Result = SECONDS2CLOCK(Time)
;
; INPUTS:
; 
;       Time - Time value in seconds.
;
; KEYWORDS:
;
;       SECONDS_FORMAT = IDL format code used to display value of
;       SECONDS.FRACTIONAL_SECONDS.  Default is '(F4.1)'.  
;
; OUTPUTS:
; 
;       This function returns a string constant.
;
; EXAMPLE:
;
;	X=SECONDS2CLOCK(106272.)
;
; MODIFICATION HISTORY:
; 
; 	David L. Windt, Columbia University, 10-Jul-2003
; 	windt@astro.columbia.edu
;         
;-
function seconds2clock,time,seconds_format=seconds_format

on_error,2

if n_params() ne 1 then return,''

ttime=abs(time)

days=fix(ttime/60./60./24.)

ttime=ttime-days*60.*60.*24.

hours=fix(ttime/60./60.)

ttime=ttime-hours*60.*60.

minutes=fix(ttime/60.)

seconds=ttime-minutes*60.

if n_elements(seconds_format) ne 1 then $
  seconds_format='(F04.1)'

time$=((time/abs(time) lt 0) ? '-' : '')+ $
  strtrim(days,2)+':'+ $
  strtrim(string(hours,format='(I2.2)'),2)+':'+ $
  strtrim(string(minutes,format='(I2.2)'),2)+':'+ $  
  strtrim(string(seconds,format=seconds_format),2)
return,time$
end
